Vendored static assets
======================

Via: https://getbootstrap.com/docs/4.6/getting-started/introduction/

- ``js/jquery-3.5.1.slim.min.js``: https://code.jquery.com/jquery-3.5.1.slim.min.js
- ``js/bootstrap.bundle.min.js``: https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js

Via: https://bootswatch.com/

- ``css/bootstrap-darkly.min.css``: https://bootswatch.com/4/darkly/bootstrap.min.css
- ``css/bootstrap-flatly.min.css``: https://bootswatch.com/4/flatly/bootstrap.min.css

We have a local edit of the bootswatch files to remove unnecessary google font imports, see: https://github.com/thomaspark/bootswatch/issues/573
